==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.tools.database/src/com/openexchange/office/tools/database/DatabaseException.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.tools.database;

import java.util.HashMap;
import java.util.Map;

/**
 * {@link DatabaseException}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.10.1
 */
@SuppressWarnings("serial")
public class DatabaseException extends Exception {
	private Map<String, String> dbProperties = new HashMap<>();;

    /**
     * Initializes a new {@link DatabaseException}.
     */
    public DatabaseException() {
        super();
    }

    /**
     * Initializes a new {@link DatabaseException}.
     * @param message
     */
    public DatabaseException(String message) {
        super(message);
    }

    /**
     * Initializes a new {@link DatabaseException}.
     * @param message
     */
    public DatabaseException(String message, Throwable e) {
        super(message, e);
    }

    /**
     * Initializes a new {@link DatabaseException}.
     * @param message
     */
    public DatabaseException(String message, Throwable e, Map<String, String> properties) {
        super(message, e);
        dbProperties = properties;
    }

    /**
     * Provides more information about the database properties
     * used, when the exception occurred. Can be used
     * @return
     */
    public Map<String, String> getDBProperties() {
        return dbProperties;
    }
}

==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.tools.database/src/com/openexchange/office/tools/database/DatabaseException.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.tools.database;

import java.util.HashMap;
import java.util.Map;

/**
 * {@link DatabaseException}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.10.1
 */
@SuppressWarnings("serial")
public class DatabaseException extends Exception {
	private Map<String, String> dbProperties = new HashMap<>();;

    /**
     * Initializes a new {@link DatabaseException}.
     */
    public DatabaseException() {
        super();
    }

    /**
     * Initializes a new {@link DatabaseException}.
     * @param message
     */
    public DatabaseException(String message) {
        super(message);
    }

    /**
     * Initializes a new {@link DatabaseException}.
     * @param message
     */
    public DatabaseException(String message, Throwable e) {
        super(message, e);
    }

    /**
     * Initializes a new {@link DatabaseException}.
     * @param message
     */
    public DatabaseException(String message, Throwable e, Map<String, String> properties) {
        super(message, e);
        dbProperties = properties;
    }

    /**
     * Provides more information about the database properties
     * used, when the exception occurred. Can be used
     * @return
     */
    public Map<String, String> getDBProperties() {
        return dbProperties;
    }

	@Override
	public String getMessage() {
      final Map<String, String> dbProps = getDBProperties();

      final StringBuffer tmp = new StringBuffer(super.getMessage());
      tmp.append(", database connection properties: ");
      tmp.append(getDatabasePropertiesAsString(dbProps));
      return tmp.toString();
	}

    private static String getDatabasePropertiesAsString(final Map<String, String> props) {
	  final StringBuffer tmp = new StringBuffer(256);
	  if ((null != props) && !props.isEmpty()) {
	      boolean first = true;
	      for (String key : props.keySet()) {
	          if (first) {
	             first = false;
	          } else {
	              tmp.append(", ");
	          }
	          tmp.append(key);
	          tmp.append("=");
	          tmp.append(props.get(key));
	      }
	  }
	
	  return tmp.toString();
	}    
}
